import { Body, Heading } from "@equilab/ui-curated";
import React from "react";
import styled from "styled-components";
import Logo from "../components/mainpage/logo";

const PolicyContainer = styled.div`
  background: #2e3330;
  padding: 32px;

  ${({ theme }) => theme.breakpoints.up("m")} {
    padding: 64px 164px;
    & .content {
      max-width: 648px;
    }
  }

  & .smallHeading {
    margin: 64px 0px 24px 0px;
  }

  & .largeHeading {
    margin: 72px 0px 24px 0px;
  }
`;

const SmallHeading: React.FC<{ children?: React.ReactNode }> = ({
  children,
}) => {
  return (
    <Heading size="s" className="smallHeading" as="div">
      {children}
    </Heading>
  );
};

const LargeHeading: React.FC<{ children?: React.ReactNode }> = ({
  children,
}) => {
  return (
    <Heading size="m" className="largeHeading" as="div">
      {children}
    </Heading>
  );
};

const PrivacyPolicy: React.FC = () => {
  return (
    <PolicyContainer>
      <div className="content">
        <Logo />
        <LargeHeading>Luminous Art Foundation Privacy Policy</LargeHeading>
        <Body>
          Luminous takes your privacy very seriously. Please read the following
          to learn more about Luminous Privacy Policy (“Policy“). This Policy
          details how Luminous and Curated! receives, collects, and uses
          information in connection with your visits to
          https://luminous.foundation (and all associated resources, subdomains
          or otherwise related web pages (the “Website“).).
        </Body>
        <SmallHeading>
          What personal information do we collect from the people who visit our
          blog, website, or app?
        </SmallHeading>
        <Body>
          When using our site, you may be asked to enter your name, email
          address, or other details to help you with your experience.
        </Body>
        <SmallHeading>Why do we collect your information?</SmallHeading>
        <Body>
          To provide you with our services, we need to collect some personal
          data, and are sometimes obliged to do so under law.
        </Body>
        <SmallHeading>When do we collect information?</SmallHeading>
        <Body>
          We collect information from you when you subscribe to a newsletter,
          fill out a form, or enter information on our site.
        </Body>
        <SmallHeading>How do we use your information?</SmallHeading>
        <Body>
          We may use information we collect from you when you register, sign up
          for our newsletter, respond to a survey or marketing communication,
          browse the website, or use certain site features in the following
          ways:
          <ul>
            <li>
              To send periodic emails with news, Luminous and Curated! platform
              updates
            </li>
            <li>
              To follow up with users after correspondence (live chat, email, or
              phone inquiries)
            </li>
          </ul>
        </Body>
        <SmallHeading>For how long do we retain your information?</SmallHeading>
        <Body>
          We will retain your information for as long as your account is active,
          your information is needed to provide you services, or as long as we
          are required to fulfill our legal obligations. By contacting us at
          privacy@curated.me, you can at any time obtain confirmation of whether
          or not your personal data is being processed.
        </Body>
        <SmallHeading>How do we protect your information?</SmallHeading>
        <Body>
          We only provide information. Your personal information is contained
          behind secured networks accessible only by a limited number of people
          who have special access rights. They are furthermore required to keep
          this information confidential. In addition, any sensitive information
          or credit card numbers you supply is encrypted via Secure Socket Layer
          (SSL) technology. <br /> We implement a variety of security measures
          when a user enters, submits, or accesses their information to maintain
          your information safely.
        </Body>
        <SmallHeading>
          What rights do you have to your information?
        </SmallHeading>
        <Body>
          All the information we collect on you will always belong to you. But
          we are a collector and a processor of your information. That implies
          certain obligations to respect your rights to such information and
          facilitate the exercise of your rights in respect to the information.
          In order to use any of your rights at any time, please contact us and
          we will facilitate the exercising of your rights free of charge.
        </Body>
        <SmallHeading>Do we use cookies?</SmallHeading>
        <Body>
          Yes. Cookies are small files that a site or its service provider
          transfers to your computer&apos;s hard drive through your web browser
          (if you allow it), enabling the site&apos;s or service provider&apos;s
          systems to recognize your browser, capture, and remember certain
          information. For instance, we use cookies to help us remember and
          process the items in your shopping cart. They also help us understand
          your preferences based on previous or current site activity, which
          lets us provide you with improved services. We also use cookies to
          help us compile aggregate data about site traffic and site
          interaction, so that we can offer better site experiences and tools in
          the future.
        </Body>
        <SmallHeading>We use cookies to:</SmallHeading>
        <Body>
          <ul>
            <li>
              Understand and save a user&apos;s preferences for future visits.
            </li>
            <li>Keep track of advertisements.</li>
            <li>
              Compile aggregate data about site traffic and site interactions to
              offer better site experiences and tools in the future. We may also
              use trusted third-party services that track this information on
              our behalf.
            </li>
          </ul>
          You can choose to have your computer warn you each time a cookie is
          sent, or you can choose to turn off all cookies. You do this through
          your browser settings. Since every browser is a little different, look
          through your browser&apos;s Help Menu to learn the correct way to
          modify your cookie settings.
          <br />
          <br />
          If you turn cookies off, some of the features that make your site
          experience more efficient may not function properly.
        </Body>
        <SmallHeading>Third-party disclosure</SmallHeading>
        <Body>
          We do not sell, trade, or otherwise transfer your personally
          identifiable information to outside parties unless we provide users
          with advance notice. This does not include website hosting partners
          and other parties who assist us in operating our website, conducting
          our business, or serving our users, so long as those parties agree to
          keep this information confidential. We may also release information
          when appropriate in order to comply with the law, enforce our site
          policies, or protect our rights, property, or safety, or those of
          others.
          <br />
          <br />
          But non-personally identifiable visitor information may be provided to
          other parties for marketing, advertising, or other uses.
        </Body>
        <SmallHeading>Third-party links</SmallHeading>
        <Body>
          Google
          <br />
          <br />
          Google&apos;s advertising requirements can be summed up by its
          advertising principles, which provide a positive experience
          https://support.google.com/adwordspolicy/ answer/1316548?hl=en for
          users.
          <br />
          <br />
          We use Google products on our website.
          <br />
          <br />
          Google, as a third-party vendor, uses cookies to serve ads on our
          site. Google&apos;s use of the DART cookie enables it to serve ads to
          our users based on previous visits to our site and other sites on the
          internet. Users may opt out of using the DART cookie by visiting the
          Google Ad and Content Network privacy policy.
          <br />
          <br />
          We have implemented the following:
          <ul>
            <li>Google Display Network Impression Reporting</li>
            <li>Demographics and Interests Reporting</li>
            <li>DoubleClick Platform Integration</li>
          </ul>
          Along with third-party vendors such as Google, we use first-party
          cookies (such as the Google Analytics cookies) or other third-party
          identifiers together to compile data regarding user interactions with
          ad impressions and other ad service functions as they relate to our
          website.
        </Body>
        <SmallHeading>Opting out:</SmallHeading>
        <Body>
          Users can set preferences for how Google advertises to you by using
          the Google Ad Settings page. Alternatively, you can opt out by
          visiting the Network Advertising Initiative Opt Out page, or by using
          the Google Analytics Opt Out Browser add-on.
        </Body>
        <SmallHeading>Changes to the policy</SmallHeading>
        <Body>
          Luminous has discretion to update this Policy at any time, so you
          should periodically check this Policy. Your continued use of the
          service after we post any modifications to the Policy on this page
          will constitute your acknowledgment of the modifications, as well as
          your consent to abide and be bound by the modified Policy. You
          acknowledge and agree that it is your responsibility to review this
          Policy for modifications.
        </Body>
        <SmallHeading>Contacting Us</SmallHeading>
        <Body>
          If you have any questions about this Policy, wish to exercise any of
          your rights to personal data and information, or file a complaint,
          please contact us at privacy@curated.me.
        </Body>
        <LargeHeading>Disclaimer</LargeHeading>
        <SmallHeading>Website disclaimer</SmallHeading>
        <Body>
          The information provided by Luminous (“we,” “us,” or “our” on the
          “Website”) is for general informational purposes only. All information
          on the Site is provided in good faith, however we make no
          representation or warranty of any kind, express or implied, regarding
          the accuracy, adequacy, validity, reliability, availability, or
          completeness of any information on the Site. Under no circumstance
          shall we have any liability to you for any loss or damage of any kind
          incurred as a result of the use of the site or reliance on any
          information provided by the site. your use of the site and your
          reliance on any information on the site is solely at your own risk.
        </Body>
        <SmallHeading>External links disclaimer</SmallHeading>
        <Body>
          The Site cannot and does not contain legal advice. The legal
          information is provided for general informational and educational
          purposes only, and is not a substitute for professional advice. Before
          taking any actions based upon such information, we encourage you to
          consult with the appropriate professionals. We do not provide any kind
          of legal advice. THE USE OR RELIANCE OF ANY INFORMATION CONTAINED ON
          THIS SITE IS SOLELY AT YOUR OWN RISK.
        </Body>
        <SmallHeading>Testimonials disclaimer</SmallHeading>
        <Body>
          The Site may contain testimonials from users of our products or
          services. These testimonials reflect the real-life experiences and
          opinions of such users. However, the experiences are personal to those
          particular users, and may not necessarily be representative of how
          other users feel about our products or services. We do not claim, and
          you should not assume, that all users will have the same experiences.
          Your individual results may vary.
          <br />
          <br />
          The testimonials on the Site are submitted in various forms such as
          text, audio, and video, and are reviewed by us before being posted.
          They appear on the Site verbatim as given by the users, except for the
          correction of grammar or typing errors. Some testimonials may have
          been shortened for the sake of brevity where the full testimonial
          contained extraneous information not relevant to the general public.
          <br />
          <br />
          The views and opinions contained in the testimonials belong solely to
          the individual user and do not reflect our own views or opinions. We
          are not affiliated with users who provide testimonials, and users are
          not paid or otherwise compensated for their testimonials.
        </Body>
      </div>
    </PolicyContainer>
  );
};

export default PrivacyPolicy;
